==> keanu_etl-0.2-py3-none-any.whl: keanu/util.py <==
import re
import os
import click
from functools import reduce
from operator import setitem
from glob import glob
from .load_script import LoadScript
import pygments
import pygments.formatters
import pygments.lexers

terminal = pygments.formatters.get_formatter_by_name('console256')
mysql = pygments.lexers.get_lexer_by_name('mysql') 

def highlight_sql(code):
    ends_with_nl = code.endswith("\n")
    c = pygments.highlight(code, mysql, terminal)
    if not ends_with_nl:
        c = c.rstrip()
    return c

def get_scripts(sqldir, mode, source, destination):
    files = glob(os.path.join(sqldir, '**/*.sql'), recursive=True)
    if len(files) == 0:
        raise click.BadParameter('No script files found in {}'.format(sqldir), param_hint='sqldir')
    scripts = list(map(lambda fn: LoadScript(fn, **opts), files))
    LoadScript.sort(scripts)
    return scripts

def filter_scripts_by_order(scripts, order):
    if re.match(r"\d+(:\d*)?(,\d+(:\d*?)?)*$", order) is None:
        raise click.ClickException('Incorrect order format. I need comma separted list of order numbers or ranges in format start:end (excluding end)')

    max_order = max(scripts, key=lambda s: s.order).order
    scripts_by_order = reduce(lambda d,s: setitem(d, s.order, d.get(s.order, []) + [s]) or d,
                              scripts, {})
    ol = order.split(',')
    def order_numbers(o):
        if ':' in o:
            start, end = o.split(':')
            if end == '':
                end = max_order + 1
            return list(range(int(start), int(end)))
        else:
            return [int(o)]

    out = []
    for o in reduce(lambda a,b: a+b, map(order_numbers, ol)):
        try:
            out += scripts_by_order.pop(o)
        except KeyError:
            pass

    return out

==> keanu_etl-0.11.2rc1-py3-none-any.whl: keanu/util.py <==
import re
import os
import click
from functools import reduce
from operator import setitem
from glob import glob
from .sql_loader import SqlLoader
import pygments
import pygments.formatters
import pygments.lexers

terminal = pygments.formatters.get_formatter_by_name('console256')
mysql = pygments.lexers.get_lexer_by_name('mysql') 

def highlight_sql(code):
    ends_with_nl = code.endswith("\n")
    c = pygments.highlight(code, mysql, terminal)
    if not ends_with_nl:
        c = c.rstrip()
    return c

def get_scripts(sqldir, mode, source, destination):
    files = glob(os.path.join(sqldir, '**/*.sql'), recursive=True)
    if len(files) == 0:
        raise click.BadParameter('No script files found in {}'.format(sqldir), param_hint='sqldir')
    scripts = list(map(lambda fn: SqlLoader(fn, **opts), files))
    SqlLoader.sort(scripts)
    return scripts

def sort_scripts(scripts):
    return scripts.sort(key=operator.attrgetter('order'))


def filter_scripts_by_order(scripts, order):
    if re.match(r"\d+(:\d*)?(,\d+(:\d*?)?)*$", order) is None:
        raise click.ClickException('Incorrect order format. I need comma separted list of order numbers or ranges in format start:end (excluding end)')

    max_order = max(scripts, key=lambda s: s.order).order
    scripts_by_order = reduce(lambda d,s: setitem(d, s.order, d.get(s.order, []) + [s]) or d,
                              scripts, {})
    ol = order.split(',')
    def order_numbers(o):
        if ':' in o:
            start, end = o.split(':')
            if end == '':
                end = max_order + 1
            return list(range(int(start), int(end)))
        else:
            return [int(o)]

    out = []
    for o in reduce(lambda a,b: a+b, map(order_numbers, ol)):
        try:
            out += scripts_by_order.pop(o)
        except KeyError:
            pass

    return out
